/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer;

import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import org.dive4elements.river.model.GrainFraction;


public class ImportGrainFraction {

    private static final Logger log =
        Logger.getLogger(ImportGrainFraction.class);

    private String name;

    private Double lower;
    private Double upper;

    private GrainFraction peer;


    public ImportGrainFraction(String name) {
        this.name = name;
    }


    public ImportGrainFraction(
        String     name,
        Double     lower,
        Double     upper
    ) {
        this.name  = name;
        this.lower = lower;
        this.upper = upper;
    }


    public void storeDependencies() {
        log.debug("store dependencies");

        getPeer();
    }


    public GrainFraction getPeer() {
        log.debug("get peer");

        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();
            Query query = session.createQuery(
                "from GrainFraction where " +
                "   name=:name and " +
                "   lower=:lower and " +
                "   upper=:upper"
            );

            query.setParameter("name", name);
            query.setParameter("lower", lower);
            query.setParameter("upper", upper);

            List<GrainFraction> fractions = query.list();
            if (fractions.isEmpty()) {
                log.info("create new GrainFraction");

                peer = new GrainFraction(name, lower, upper);
                session.save(peer);
            }
            else {
                peer = fractions.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
